#!usr/bin/env python
# -*- coding: utf8 -*-

# -----------------------------------------------------------------------------
#   File: acoustic_converter.py (as part of project URUMETRICS)
#   Created: 28/07/2022 11:10
#   Last Modified: 28/07/2022 11:10
# -----------------------------------------------------------------------------
#   Author: William N. Havard
#           Postdoctoral Researcher
#
#   Mail  : william.havard@ens.fr / william.havard@gmail.com
#  
#   Institution: ENS / Laboratoire de Sciences Cognitives et Psycholinguistique
#
# ------------------------------------------------------------------------------
#   Description: 
#       • 
# -----------------------------------------------------------------------------

import pandas as pd
from ChildProject.annotations import AnnotationConverter

class AcousticConverter(AnnotationConverter):
    FORMAT = "acoustic"

    @staticmethod
    def convert(filename: str, source_file: str = "", **kwargs) -> pd.DataFrame:
        df = pd.read_csv(
            filename,
            sep=r",",
            header=0,
            engine="python",
        )

        n_recordings = len(df["file"].unique())
        if  n_recordings > 1 and not source_file:
            print(
                f"""WARNING: {filename} contains annotations from {n_recordings} different audio files, """
                """but no filter was specified which means all of these annotations will be imported.\n"""
                """as if they belonged to the same recording. Please make sure this is the intended behavior """
                """(it probably isn't)."""
            )

        if source_file:
            df = df[df["file"].str.contains(source_file)]

        df.drop(columns=["file"], inplace=True)

        return df

