#!usr/bin/env python
# -*- coding: utf8 -*-

# -----------------------------------------------------------------------------
#   File: prepare_data_set.py (as part of project URUMETRICS)
#   Created: 20/05/2022 15:48
#   Last Modified: 20/05/2022 15:48
# -----------------------------------------------------------------------------
#   Author: William N. Havard
#           Postdoctoral Researcher
#
#   Mail  : william.havard@ens.fr / william.havard@gmail.com
#  
#   Institution: ENS / Laboratoire de Sciences Cognitives et Psycholinguistique
#
# ------------------------------------------------------------------------------
#   Description: 
#       • This script creates all the necessary directories to drop and
#         process the annotation files.
# -----------------------------------------------------------------------------

import logging
import os
import sys

from consts import ANNOTATION_TYPES

logger = logging.getLogger(__name__)

def create_child_project_directories(data_path):
    """
    Creates all the directories required by ChildProject
    :param data_path: path where the directories should be created
    :type data_path: str
    :return: None
    :rtype: None
    """
    child_project_dirs = [os.path.join(data_path, 'extra'),
                          os.path.join(data_path, 'metadata'),
                          os.path.join(data_path, 'annotations'),
                          os.path.join(data_path, 'recordings', 'raw')]

    annotations_dir = [os.path.join(data_path, 'annotations', ann_type.name.lower(), 'raw')
                       for ann_type in ANNOTATION_TYPES]

    all_dirs = child_project_dirs + annotations_dir

    for p in all_dirs:
        if not os.path.exists(p):
            os.makedirs(p)
        else:
            logging.info('{} already exists.'.format(p))


def main():
    project_path = '.'

    create_child_project_directories(project_path)


if __name__ == '__main__':
    logging.basicConfig(level=logging.INFO)

    try:
        main()
        sys.exit(0)
    except Exception as e:
        print(e)
        sys.exit(1)